structure(list(method = "POST", url = "/logicalpath?logical-path=%2FtempZone%2Fhome%2Frods%2Ftestthat%2Fa&collection=1&create-parent-collections=0", 
    status_code = 200L, headers = structure(list(Server = "nginx/1.23.1", 
        Date = "Sun, 29 Oct 2023 09:45:28 GMT", `Content-Length` = "0", 
        Connection = "keep-alive", `Access-Control-Allow-Origin` = "*", 
        `Access-Control-Allow-Headers` = "*", `Access-Control-Allow-Methods` = "AUTHORIZATION,ACCEPT,GET,POST,OPTIONS,PUT,DELETE"), class = "httr2_headers"), 
    body = raw(0)), class = "httr2_response")
